/*
 * (c) Copyright 2015 -- Anders Torger
 *
 * This program is open source. For license terms, see the LICENSE file.
 *
 */
#ifndef DCAMPROF_H_
#define DCAMPROF_H_

#include <stdio.h>
#include <stdbool.h>

#include <colmath.h>

struct cam2xyz_patch {
    spectrum_t *spectrum;
    int class;
    double k_lch[3];
    double m_de;
    double de;
    double w;
    v3 cam;
    v3 xyz;
};

struct patch_set {
    size_t patch_count;
#define TARGET_MAX_CLASS_COUNT 24
#define TARGET_CLASS_NAME_SIZE 24
    char class_names[TARGET_MAX_CLASS_COUNT][TARGET_CLASS_NAME_SIZE];
    struct cam2xyz_patch patch[];
};

struct dcam_ssf {
    char *camera_name;
    struct observer ssf;
};

struct chromalut_t_;
typedef struct chromalut_t_ chromalut_t;

struct dcam_profile {
    enum exif_lightsource illuminant_name;
    spectrum_t *illuminant_spec;
    m3x3 color_matrix;
    m3x3 forward_matrix;
    chromalut_t *lut;
};

void
dcam_profile_delete(struct dcam_profile *prof);

FILE *
open_log_file(const char dir[],
              const char name[]);

struct patch_set *
normalize_patch_set(const struct patch_set *ps);

#endif
