/*
 * (c) Copyright 2015 -- Anders Torger
 *
 * This program is open source. For license terms, see the LICENSE file.
 *
 */
#ifndef PROFIO_H_
#define PROFIO_H_

#include <stdbool.h>
#include <stdio.h>

#include <colmath.h>

enum dng_embed_policy {

        // Freely embedable and copyable into installations that encounter this
        // profile, so long as the profile is only used to process DNG files.

        pepAllowCopying                         = 0,

        // Can be embeded in a DNG for portable processing, but cannot be used
        // to process other files that the profile is not embedded in.

        pepEmbedIfUsed                          = 1,

        // Can only be used if installed on the machine processing the file.
        // Note that this only applies to stand-alone profiles.  Profiles that
        // are already embedded inside a DNG file allowed to remain embedded
        // in that DNG, even if the DNG is resaved.

        pepEmbedNever                           = 2,

        // No restricts on profile use or embedding.

        pepNoRestrictions                       = 3

};

struct profio_dcp {
    char *camera_model;
    char *profile_name;
    char *copyright;
    char *calibration_signature;
    enum dng_embed_policy embed_policy;
    enum exif_lightsource ill[2];
    m3x3 cm[2];
    m3x3 fm[2];
    int ill_count;
    uint32_t hsmdims[3];
    uint32_t lookdims[3];
    bool huesatmap_srgb_gamma;
    bool looktable_srgb_gamma;
    bool black_render_none;
    v3 *huesatmap[2];
    v3 *looktable;
    double baseline_exposure_offset;
    double *tonecurve;
    int tonecurve_len;
    // bools for optional tags
    struct {
        bool fm;
        bool huesatmap_srgb_gamma;
        bool looktable_srgb_gamma;
        bool black_render_none;
        bool baseline_exposure_offset;
        bool embed_policy;
    } has;
};

const char *
exif_lightsource_ntoa(enum exif_lightsource ls);

enum exif_lightsource
exif_lightsource_aton(const char str[]);

double
exif_lightsource_temp(enum exif_lightsource ls);

struct profio_dcp *
profio_dcp_parse(const char filename[],
                 bool error_is_fatal);

void
profio_dcp_json(struct profio_dcp *dcp,
                FILE *stream);

bool
profio_dcp_write(const struct profio_dcp *dcp,
                 const char filename[],
                 bool error_is_fatal);

void
profio_dcp_delete(struct profio_dcp *dcp);

#endif
